@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2013  Zarafa B.V.
+ * Copyright 2005 - 2014  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -437,6 +437,13 @@ typedef struct SYSTEMTIME {
 	WORD wMilliseconds;
 } SYSTEMTIME, *PSYSTEMTIME;
 
+typedef struct TZREG {
+	LONG bias;
+	LONG stdbias;
+	LONG dstbias;
+	SYSTEMTIME stStandardDate;
+	SYSTEMTIME stDaylightDate;
+} TZREG, *PTZREG;
 
 /* IUnknown Interface */
 class IUnknown {
